==> pax-exam-container-karaf-4.9.2-sources.jar: org/ops4j/pax/exam/karaf/options/KarafDistributionConfigurationFilePutOption.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ops4j.pax.exam.karaf.options;

/**
 * This option allows to configure each configuration fille based on the karaf.home location. The value is "put". Which
 * means it is either replaced or added.
 * <p>
 * If you like to extend an option (e.g. make a=b to a=b,c) please make use of the
 * {@link KarafDistributionConfigurationFileExtendOption}.
 */
public class KarafDistributionConfigurationFilePutOption extends KarafDistributionConfigurationFileOption {

    public KarafDistributionConfigurationFilePutOption(String configurationFilePath, String key, String value) {
        super(configurationFilePath, key, value);
    }

    public KarafDistributionConfigurationFilePutOption(ConfigurationPointer pointer, String value) {
        super(pointer, value);
    }

}

==> pax-exam-container-karaf-4.13.0-sources.jar: org/ops4j/pax/exam/karaf/options/KarafDistributionConfigurationFilePutOption.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ops4j.pax.exam.karaf.options;

/**
 * This option allows to configure each configuration fille based on the karaf.home location. The value is "put". Which
 * means it is either replaced or added.
 * <p>
 * If you like to extend an option (e.g. make a=b to a=b,c) please make use of the
 * {@link KarafDistributionConfigurationFileExtendOption}.
 */
public class KarafDistributionConfigurationFilePutOption extends KarafDistributionConfigurationFileOption {

    public KarafDistributionConfigurationFilePutOption(String configurationFilePath, String key, Object value) {
        super(configurationFilePath, key, value);
    }

    public KarafDistributionConfigurationFilePutOption(ConfigurationPointer pointer, Object value) {
        super(pointer, value);
    }

}
